==> kubernetes-model-apiextensions-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class JSONSchemaPropsOrStringArrayFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent<A>{
  public JSONSchemaPropsOrStringArrayFluentImpl() {
  }
  public JSONSchemaPropsOrStringArrayFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArray instance) {
    this.withProperty(instance.getProperty()); 
    this.withSchema(instance.getSchema()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> property = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder schema;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToProperty(java.lang.Integer index,java.lang.String item) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    this.property.add(index, item);
    return (A)this;
  }
  public A setToProperty(java.lang.Integer index,java.lang.String item) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    this.property.set(index, item); return (A)this;
  }
  public A addToProperty(java.lang.String... items) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.property.add(item);} return (A)this;
  }
  public A addAllToProperty(java.util.Collection<java.lang.String> items) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.property.add(item);} return (A)this;
  }
  public A removeFromProperty(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.property!= null){ this.property.remove(item);}} return (A)this;
  }
  public A removeAllFromProperty(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.property!= null){ this.property.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getProperty() {
    return this.property;
  }
  public java.lang.String getProperty(java.lang.Integer index) {
    return this.property.get(index);
  }
  public java.lang.String getFirstProperty() {
    return this.property.get(0);
  }
  public java.lang.String getLastProperty() {
    return this.property.get(property.size() - 1);
  }
  public java.lang.String getMatchingProperty(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: property) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingProperty(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: property) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withProperty(java.util.List<java.lang.String> property) {
    if (property != null) {this.property = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : property){this.addToProperty(item);}} else { this.property = null;} return (A) this;
  }
  public A withProperty(java.lang.String... property) {
    if (this.property != null) {this.property.clear();}
    if (property != null) {for (java.lang.String item :property){ this.addToProperty(item);}} return (A) this;
  }
  public java.lang.Boolean hasProperty() {
    return property != null && !property.isEmpty();
  }
  public A addNewProperty(java.lang.String arg0) {
    return (A)addToProperty(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema() {
    return this.schema!=null?this.schema.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema() {
    return this.schema!=null?this.schema.build():null;
  }
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema) {
    _visitables.get("schema").remove(this.schema);
    if (schema!=null){ this.schema= new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(schema); _visitables.get("schema").add(this.schema);} return (A) this;
  }
  public java.lang.Boolean hasSchema() {
    return this.schema != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchema() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluentImpl.SchemaNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluentImpl.SchemaNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editSchema() {
    return withNewSchemaLike(getSchema());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchema() {
    return withNewSchemaLike(getSchema() != null ? getSchema(): new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return withNewSchemaLike(getSchema() != null ? getSchema(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    JSONSchemaPropsOrStringArrayFluentImpl that = (JSONSchemaPropsOrStringArrayFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (schema != null ? !schema.equals(that.schema) :that.schema != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  schema,  additionalProperties,  super.hashCode());
  }
  public class SchemaNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SchemaNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this, item);
    }
    SchemaNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder builder;
    public N and() {
      return (N) JSONSchemaPropsOrStringArrayFluentImpl.this.withSchema(builder.build());
    }
    public N endSchema() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrStringArrayFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class JSONSchemaPropsOrStringArrayFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent<A>{
  public JSONSchemaPropsOrStringArrayFluentImpl() {
  }
  public JSONSchemaPropsOrStringArrayFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArray instance) {
    this.withProperty(instance.getProperty()); 
    this.withSchema(instance.getSchema()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> property = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder schema;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToProperty(java.lang.Integer index,java.lang.String item) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    this.property.add(index, item);
    return (A)this;
  }
  public A setToProperty(java.lang.Integer index,java.lang.String item) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    this.property.set(index, item); return (A)this;
  }
  public A addToProperty(java.lang.String... items) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.property.add(item);} return (A)this;
  }
  public A addAllToProperty(java.util.Collection<java.lang.String> items) {
    if (this.property == null) {this.property = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.property.add(item);} return (A)this;
  }
  public A removeFromProperty(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.property!= null){ this.property.remove(item);}} return (A)this;
  }
  public A removeAllFromProperty(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.property!= null){ this.property.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getProperty() {
    return this.property;
  }
  public java.lang.String getProperty(java.lang.Integer index) {
    return this.property.get(index);
  }
  public java.lang.String getFirstProperty() {
    return this.property.get(0);
  }
  public java.lang.String getLastProperty() {
    return this.property.get(property.size() - 1);
  }
  public java.lang.String getMatchingProperty(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: property) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingProperty(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: property) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withProperty(java.util.List<java.lang.String> property) {
    if (property != null) {this.property = new java.util.ArrayList(); for (java.lang.String item : property){this.addToProperty(item);}} else { this.property = null;} return (A) this;
  }
  public A withProperty(java.lang.String... property) {
    if (this.property != null) {this.property.clear();}
    if (property != null) {for (java.lang.String item :property){ this.addToProperty(item);}} return (A) this;
  }
  public java.lang.Boolean hasProperty() {
    return property != null && !property.isEmpty();
  }
  public A addNewProperty(java.lang.String arg0) {
    return (A)addToProperty(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSchema instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema() {
    return this.schema!=null?this.schema.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema() {
    return this.schema!=null?this.schema.build():null;
  }
  public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema) {
    _visitables.get("schema").remove(this.schema);
    if (schema!=null){ this.schema= new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(schema); _visitables.get("schema").add(this.schema);} return (A) this;
  }
  public java.lang.Boolean hasSchema() {
    return this.schema != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchema() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluentImpl.SchemaNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluentImpl.SchemaNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editSchema() {
    return withNewSchemaLike(getSchema());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchema() {
    return withNewSchemaLike(getSchema() != null ? getSchema(): new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
    return withNewSchemaLike(getSchema() != null ? getSchema(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    JSONSchemaPropsOrStringArrayFluentImpl that = (JSONSchemaPropsOrStringArrayFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (schema != null ? !schema.equals(that.schema) :that.schema != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  schema,  additionalProperties,  super.hashCode());
  }
  public class SchemaNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrStringArrayFluent.SchemaNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SchemaNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this, item);
    }
    SchemaNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder builder;
    public N and() {
      return (N) JSONSchemaPropsOrStringArrayFluentImpl.this.withSchema(builder.build());
    }
    public N endSchema() {
      return and();
    }
    
  }
  
}
